"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isAUID = exports.generateAUID = void 0;
const crypto_1 = require("crypto");
/**
 * Generates a crytografically strong AUID
 *
 * With `(2 ^ 4) ^ (16*4)` or `2 ^ 256` or `1.1579209e+77` possible combinations
 */
function generateAUID() {
    // Generate 32 bytes (256 bits), which is enough to create the entire AUID.
    const bytes = (0, crypto_1.randomBytes)(32).toString('hex'); // 64 hex characters
    // Format the AUID by slicing the string into 4 parts of 16 characters each.
    return `${bytes.slice(0, 16)}-${bytes.slice(16, 32)}-${bytes.slice(32, 48)}-${bytes.slice(48, 64)}`;
}
exports.generateAUID = generateAUID;
/**
 * Fullproof regex for AUIDs
 */
exports.isAUID = new RegExp(/^[a-f0-9]{16}-[a-f0-9]{16}-[a-f0-9]{16}-[a-f0-9]{16}$/);
