import { log } from "console";
import { randomBytes } from "crypto";

/**
 * Template string type for AUIDs
 */
export type AUID = `${string}-${string}-${string}-${string}`;

/**
 * Generates a crytografically strong AUID
 * 
 * With `(2 ^ 4) ^ (16*4)` or `2 ^ 256` or `1.1579209e+77` possible combinations
 */
export function generateAUID(): AUID {
    // Generate 32 bytes (256 bits), which is enough to create the entire AUID.
    const bytes = randomBytes(32).toString('hex'); // 64 hex characters

    // Format the AUID by slicing the string into 4 parts of 16 characters each.
    return `${bytes.slice(0, 16)}-${bytes.slice(16, 32)}-${bytes.slice(32, 48)}-${bytes.slice(48, 64)}` as AUID;
}

/**
 * Fullproof regex for AUIDs
 */
export const isAUID = new RegExp(/^[a-f0-9]{16}-[a-f0-9]{16}-[a-f0-9]{16}-[a-f0-9]{16}$/);
